Learn R Programming

epiR (version 0.9-27)

epi.RtoBUGS: R to WinBUGS data conversion

Description

Writes data from an R list to a text file in WinBUGS-compatible format.

Usage

epi.RtoBUGS(datalist, towhere)

Arguments

datalist
a list (normally, with named elements) which may include scalars, vectors, matrices, arrays of any number of dimensions, and data frames.
towhere
a character string identifying where the file is to be written.

Value

    Details

    Does not check to ensure that only numbers are being produced. In particular, factor labels in a data frame will be output to the file, which normally won't be desired.

    References

    Best, NG. WinBUGS 1.3.1 Short Course, Brisbane, November 2000.