Learn R Programming

epiR (version 0.9-11)

epi.cluster1size: Sample size under under one-stage cluster sampling

Description

Estimates the required sample size under under one-stage cluster sampling.

Usage

epi.cluster1size(n, mean, var, epsilon, method = "mean", 
   conf.level = 0.95)

Arguments

n
an integer representing the total number of clusters in the population.
mean
a number representing the population mean of the variable of interest.
var
a number representing the population variance of the variable of interest.
epsilon
the maximum relative difference between our estimate and the unknown population value.
method
a character string indicating the method to be used. Options are total, mean or mean.per.unit.
conf.level
scalar, defining the level of confidence in the computed result.

Value

  • Returns an integer defining the size of the sample required.

References

Levy PS, Lemeshow S (1999). Sampling of Populations Methods and Applications. Wiley Series in Probability and Statistics, London, pp. 258.

Examples

Run this code
## We intend to conduct a survey of residents to estimate the total number
## over 65 years of age that require the services of a nurse. There are 
## five housing complexes in the study area and we expect that there might
## be a total of around 34 residents meeting this criteria (variance 6.8).
## We would like the estimated sample size to provide us with an estimate
## that is within 10\% of the true value. How many housing complexes should
## be sampled?

epi.cluster1size(n = 5, mean = 34, var = 6.8, epsilon = 0.10, method = 
   "total", conf.level = 0.999)

## We would need a simple one-stage cluster sample of 3 housing complexes to 
## meet the specifications for this study.

Run the code above in your browser using DataLab