Learn R Programming

epiR (version 0.9-32)

epi.convgrid: Convert British National Grid georeferences to easting and northing coordinates

Description

Convert British National Grid georeferences to easting and northing coordinates.

Usage

epi.convgrid(os.refs)

Arguments

os.refs
a vector of character strings listing the British National Grid georeferences to be converted.

Value

    Examples

    Run this code
    os.refs <- c("SJ505585","SJ488573","SJ652636")
    epi.convgrid(os.refs)

    Run the code above in your browser using DataLab