Learn R Programming

epiR (version 0.9-18)

epi.dsl: Mixed-effects meta-analysis of binary outcomes using the DerSimonian and Laird method

Description

Computes individual study odds or risk ratios for binary outcome data. Computes the pooled odds or risk ratio using the DerSimonian and Laird method. Performs a test for the overall difference between groups.

Usage

epi.dsl(ev.trt, n.trt, ev.ctrl, n.ctrl, names, method = "odds.ratio", 
   conf.level = 0.95)

Arguments

ev.trt
observed number of events in the treatment group.
n.trt
number in the treatment group.
ev.ctrl
observed number of events in the control group.
n.ctrl
number in the control group.
names
character string identifying each trial.
method
a character string indicating the method to be used. Options are odds.ratio or risk.ratio.
conf.level
magnitude of the returned confidence interval. Must be a single number between 0 and 1.

Value

  • A list containing the following:
  • odds.ratiothe names of the trials specified, the odds ratios for each trial, the lower and upper bounds of the confidence interval of the odds ratio for each trial and the pooled odds ratio and the lower and upper bounds of the confidence interval of the pooled odds ratio.
  • risk.ratiothe names of the trials specified, the risk ratios for each trial, the lower and upper bounds of the confidence interval of the risk ratio for each trial and the pooled risk ratio and the lower and upper bounds of the confidence interval of the pooled risk ratio.
  • weightsthe inverse variance and DerSimonian and Laird weights for each trial.
  • heterogeneitya vector containing Q the heterogeneity test statistic, df the degrees of freedom and its associated P-value.
  • Hsqthe relative excess of the heterogeneity test statistic Q over the degrees of freedom df.
  • Isqthe percentage of total variation in study estimates that is due to heterogeneity rather than chance.
  • tau.sqthe variance of the treatment effect among trials.
  • effecta vector containing z the test statistic for overall treatment effect and its associated P-value.

References

Deeks JJ, Altman DG, Bradburn MJ (2001). Statistical methods for examining heterogeneity and combining results from several studies in meta-analysis. In: Egger M, Davey Smith G, Altman D (eds). Systematic Review in Health Care Meta-Analysis in Context. British Medical Journal, London, 2001, pp. 291 - 299. DerSimonian R, Laird N (1986). Meta-analysis in clinical trials. Controlled Clinical Trials 7: 177 - 188. Higgins J, Thompson S (2002). Quantifying heterogeneity in a meta-analysis. Statistics in Medicine 21: 1539 - 1558.

See Also

epi.iv, epi.mh, epi.smd

Examples

Run this code
data(epi.epidural)
epi.dsl(ev.trt = epi.epidural$ev.trt, n.trt = epi.epidural$n.trt, 
   ev.ctrl = epi.epidural$ev.ctrl, n.ctrl = epi.epidural$n.ctrl, 
   names = as.character(epi.epidural$trial), method = "odds.ratio", 
   conf.level = 0.05)

Run the code above in your browser using DataLab