| epi.evalue | R Documentation |
Returns a list of the point estimate, lower confidence limit, and upper confidence limit for risk, rate, odds or hazard ratio (as provided by the user) and E-values for the measure of association point estimate and the confidence interval limit closer to the null.
epi.evalue(x, measure = "risk.ratio", rare = TRUE, conf.level = 0.95)
x |
an object of class |
measure |
a character string indicating the measure used. Options are |
rare |
logical. If |
conf.level |
magnitude of the confidence interval provided in |
The E-value is the minimum strength of association, on the risk ratio scale, that an unmeasured confounder would need to have with both the exposure and the outcome to fully explain away a specific exposure-outcome association, conditional on the measured covariates included in a model (VanderWeele and Ding 2017). Larger E-values indicate that the observed association is more robust to potential unmeasured confounding.
It is usual to calculate the E-value for only the lower bound of the 95% CI when the risk ratio, odds ratio or hazard ratio is greater than 1 and for only the upper bound when the estimate is less than 1. The purpose of estimating the E-value of the 95% CI is to determine the strength of confounding required to bring the confidence limits of the risk ratio, odds ratio or hazard ratio to unity. That is, to make the estimate of the odds ratio, risk ratio or hazard ratio no longer statistically significant.
When measure == "risk.ratio" or measure == "rate.ratio" a list containing:
rr |
a data frame listing the variable name, the point estimate of the risk ratio, the lower bound of the confidence interval of the risk ratio and the upper bound of the confidence interval of the risk ratio, as entered by the user through argument |
eval |
a data frame listing |
When measure == "odds.ratio" a list containing:
or |
a data frame listing the variable name, the point estimate of the odds ratio, the lower bound of the confidence interval of the odds ratio and the upper bound of the confidence interval of the odds ratio, as entered by the user through argument |
rr |
a data frame listing the variable name, the point estimate of the risk ratio, the lower bound of the confidence interval of the risk ratio and the upper bound of the confidence interval of the risk ratio, computed using the odds ratio estimates entered by the user through argument |
eval |
a data frame listing |
When measure == "hazard.ratio" a list containing:
hr |
a data frame listing the variable name, the point estimate of the hazard ratio, the lower bound of the confidence interval of the hazard ratio and the upper bound of the confidence interval of the hazard ratio, as entered by the user through argument |
rr |
a data frame listing the variable name, the point estimate of the risk ratio, the lower bound of the confidence interval of the risk ratio and the upper bound of the confidence interval of the risk ratio, computed using the hazard ratio estimates entered by the user through argument |
eval |
a data frame listing |
Ding P, VanderWeele T, (2016) Sensitivity analysis without assumptions. Epidemiology 27: 368 - 377.
VanderWeele TJ, Ding P (2017). Sensitivity analysis in observational research: Introducing the E-value. Annals of Internal Medicine 167: 268 - 274.
## EXAMPLE 1:
## The birthwt data frame from the MASS package were collected at Baystate
## Medical Center, Springfield, Massachusetts USA in 1986. A logistic
## regression model is run to quantify the effect of smoking during pregancy
## and delivery of a low birth weight baby, controlling for the effect of race.
library(MASS)
dat.df <- birthwt; head(dat.df)
dat.glm <- glm(low ~ smoke + race, family = binomial, data = dat.df)
table(dat.df$low)
## The study outcome (low birthweight) is relatively common so we set rare =
## FALSE
epi.evalue(x = dat.glm, measure = "odds.ratio", rare = FALSE,
conf.level = 0.95)
## $or
## var est lower upper
## 1 smoke 3.054692 1.507644 6.432485
## 2 race 1.748883 1.196771 2.611134
## $rr
## var est lower upper
## 1 smoke 1.747768 1.227861 2.536234
## 2 race 1.322453 1.093970 1.615900
## $eval
## var est lower upper
## 1 smoke 2.890975 1.756806 NA
## 2 race 1.975469 1.414596 NA
## After controlling for the effect of race, the odds of delivering a low
## birth weight baby for smokers was 3.05 (95% CI 1.51 to 6.43) times that of
## non-smokers.
## After controlling for the effect of race, the risk of delivering a low
## birth weight baby for smokers was 1.75 (95% CI 1.23 to 2.53) times that of
## non-smokers.
## An unmeasured confounder in this study would need to be associated with both
## smoking and delivery of a low birth weight baby by a risk ratio of at
## least 2.89 each, above and beyond the measured covariates, to completely
## explain the observed risk ratio of 1.75.
## The E-value for the lower confidence limit is 1.76. To reduce the
## association enough that the lower bound of the risk ratio confidence limit
## (1.23) would include the null, an unmeasured confounder would still need
## to have associations of about 1.76 with both the exposure and the outcome.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.