Learn R Programming

epiR (version 0.9-15)

epi.mh: Fixed-effects meta-analysis of binary outcomes using the Mantel-Haenszel method

Description

Computes odds ratios (or risk ratios) and confidence intervals for binary outcome data. Computes the pooled odds ratio (or risk ratio) using the Mantel-Haenszel method. Performs a test of heterogeneity among trials. Performs a test for the overall difference between groups.

Usage

epi.mh(ev.trt, n.trt, ev.ctrl, n.ctrl, names, method = "odds.ratio", 
   conf.level = 0.95)

Arguments

ev.trt
observed number of events in the treatment group.
n.trt
number in the treatment group.
ev.ctrl
observed number of events in the control group.
n.ctrl
number in the control group.
names
character string identifying each trial.
method
a character string indicating the method to be used. Options are odds.ratio or risk.ratio.
conf.level
magnitude of the returned confidence interval. Must be a single number between 0 and 1.

Value

  • A list containing the following:
  • odds.ratiothe names of the trials, the odds ratio for each trial, the standard error of the odds ratio for each trial, the lower and upper bounds of the confidence interval of the odds ratio for each trial, the pooled odds ratio, the standard error of the pooled odds ratio, and the lower and upper bounds of the confidence interval of the pooled odds ratio.
  • risk.ratiothe names of the trials, the risk ratio for each trial, the standard error of the risk ratio for each trial, the lower and upper bounds of the confidence interval of the risk ratio for each trial, the pooled risk ratio, the standard error of the pooled risk ratio, and the lower and upper bounds of the confidence interval of the pooled risk ratio.
  • heterogeneitya vector containing Q the heterogeneity test statistic, df the degrees of freedom and its associated P-value.
  • Hsqthe relative excess of the heterogeneity test statistic Q over the degrees of freedom df.
  • Isqthe percentage of total variation in study estimates that is due to heterogeneity rather than chance.
  • effecta vector containing z the test statistic for overall treatment effect and its associated P-value.

Details

Under the random-effects model, the assumption of a common treatment effect is relaxed, and the effect sizes are assumed to have a normal distribution with variance tau.sq.

References

Higgins JP, Thompson SG (2002). Quantifying heterogeneity in a meta-analysis. Statistics in Medicine 21: 1539 - 1558.

See Also

epi.dsl, epi.iv, epi.smd

Examples

Run this code
data(epi.epidural)
epi.mh(ev.trt = epi.epidural$ev.trt, n.trt = epi.epidural$n.trt, 
   ev.ctrl = epi.epidural$ev.ctrl, n.ctrl = epi.epidural$n.ctrl, 
   names = as.character(epi.epidural$trial), method = "odds.ratio",
   conf.level = 0.05)

Run the code above in your browser using DataLab