epi.dsl(ev.trt, n.trt, ev.ctrl, n.ctrl, names, method = "odds.ratio",
conf.level = 0.95)odds.ratio or risk.ratio.Q the heterogeneity test statistic, df the degrees of freedom and its associated P-value.Q over the degrees of freedom df.z the test statistic for overall treatment effect and its associated P-value.epi.iv, epi.mh, epi.smddata(epi.epidural)
epi.dsl(ev.trt = epi.epidural$ev.trt, n.trt = epi.epidural$n.trt,
ev.ctrl = epi.epidural$ev.ctrl, n.ctrl = epi.epidural$n.ctrl,
names = as.character(epi.epidural$trial), method = "odds.ratio",
conf.level = 0.95)Run the code above in your browser using DataLab