## Kidney samples from 291 salmon were split with one half of the
## samples sent to each of two laboratories where an IFAT test
## was run on each sample. The following results were obtained:
## Lab 1 positive, lab 2 positive: 19
## Lab 1 positive, lab 2 negative: 10
## Lab 1 negative, lab 2 positive: 6
## Lab 1 negative, lab 2 negative: 256
epi.kappa(a = 19, b = 10, c = 6, d = 256, conf.level = 0.95)
## The McNemar's chi-squared test statistic is 1.00 (P = 0.32). We
## conclude that there is little evidence that the two laboratories
## found different proportions positive.
## The proportion of agreements after chance has been excluded is
## 0.67 (95\% CI 0.52 to 0.83). We conclude that, on the basis of
## this sample, that there is substantial agreement between the two
## laboratories.Run the code above in your browser using DataLab