Learn R Programming

epiR (version 0.9-17)

epi.prev: Estimate true prevalence

Description

Computes the true prevalence of a disease in a population on the basis of an imperfect test.

Usage

epi.prev(pos, tested, se, sp, conf.level = 0.95)

Arguments

pos
the number of positives.
tested
the number tested.
se
test sensitivity (0 - 1).
sp
test specificity (0 - 1).
conf.level
magnitude of the returned confidence interval. Must be a single number between 0 and 1.

Value

  • A list containing the following:
  • apthe point estimate of apparent prevalence, the standard error of the apparent prevalence, and the lower and upper bounds of the apparent prevalence.
  • tpthe point estimate of the true prevalence, the standard error of the true prevalence, and the lower and upper bounds of the true prevalence.

References

Abel U (1993). DieBewertung Diagnostischer Tests. hippkrates, Stuttgart. Gardener IA, Greiner M (1999). Advanced Methods for Test Validation and Interpretation in Veterinary Medicince. Freie Universitat Berlin, ISBN 3-929619-22-9; 80 pp. Messam L, Branscum A, Collins M, Gardner I (2008) Frequentist and Bayesian approaches to prevalence estimation using examples from Johne's disease. Animal Health Research Reviews 9: 1 - 23. Rogan W, Gladen B (1978). Estimating prevalence from results of a screening test. American Journal of Epidemiology 107: 71 - 76.

Examples

Run this code
## A simple random sample of 150 cows from a herd of 2560 is taken.
## Each cow is given a screening test for brucellosis which has a 
## sensitivity of 96\% and a specificity of 89\%. Of the 150 cows tested
## 23 were positive to the screening test. What is the estimated prevalence 
## of brucellosis in this herd (and its 95\% confidence interval)?

epi.prev(pos = 23, tested = 150, se = 0.96, sp = 0.89, conf.level = 0.95)

## The estimated true prevalence of brucellosis in this herd is 5.1 cases per 
## 100 cows (95\% CI 0 -- 12 cases per 100 cows).

Run the code above in your browser using DataLab