## A simple random sample of 150 cows from a herd of 2560 is taken.
## Each cow is given a screening test for brucellosis which has a
## sensitivity of 96\% and a specificity of 89\%. Of the 150 cows tested
## 23 were positive to the screening test. What is the estimated prevalence
## of brucellosis in this herd (and its 95\% confidence interval)?
epi.prev(pos = 23, tested = 150, se = 0.96, sp = 0.89, conf.level = 0.95)
## The estimated true prevalence of brucellosis in this herd is 5.1 cases per
## 100 cows (95\% CI 0 -- 12 cases per 100 cows).Run the code above in your browser using DataLab