Learn R Programming

epiR (version 2.0.91)

epi.ssdetect: Sample size to detect an event

Description

Sample size to detect at least one event (e.g., a disease-positive individual) in a population. The method adjusts sample size estimates on the basis of test sensitivity and can account for series and parallel test interpretation.

Usage

epi.ssdetect(N, pstar, se, sp, interpretation = "series", 
   covar = c(0,0), nfractional = FALSE, se.psu = 0.95, ss.se = 0.95)

Arguments

Value

A list containing the following:

performance

The sensitivity and specificity of the testing strategy.

sample.size

The required number of primary sampling units, secondary sampling units per primary sampling unit, and the total number of secondary sampling units.

References

Cannon RM (2001). Sense and sensitivity --- designing surveys based on an imperfect test. Preventive Veterinary Medicine 49: 141 - 163.

Dohoo I, Martin W, Stryhn H (2009). Veterinary Epidemiologic Research. AVC Inc, Charlottetown, Prince Edward Island, Canada, pp. 54.

MacDiarmid S (1988). Future options for brucellosis surveillance in New Zealand beef herds. New Zealand Veterinary Journal 36, 39 - 42. DOI: 10.1080/00480169.1988.35472.

Examples

Run this code
## EXAMPLE 1:
## We would like to confirm the absence of disease in a single 1000-cow 
## dairy herd. We expect the prevalence of disease in the herd to be 5%.
## We intend to use a single test with a sensitivity of 0.90 and a 
## specificity of 1.00. How many samples should we take to be 95% certain 
## that, if all tests are negative, the disease is not present?

epi.ssdetect(N = 1000, pstar = 0.05, se = 0.90, sp = 1.00, 
   interpretation = "series", covar = c(0,0), 
   nfractional = FALSE, se.psu = 0.95, ss.se = 0.95)
   
## We need to sample 62 cows.


## EXAMPLE 2:
## We would like to confirm the absence of disease in a study area. If the 
## disease is present we expect the prevalence of disease-positive herds to 
## 8% and the within-herd prevalence (for disease-positive herds) to be 5%. 
## We intend to use two tests: The first has a sensitivity and specificity of 
## 0.90 and 0.80, respectively. The second has a sensitivity and specificity 
## of 0.95 and 0.85, respectively. The two tests will be interpreted in 
## parallel. How many herds and cows within herds should we sample to be 
## 95% certain that the disease is not present in the 
## study area if all tests are negative? There area is comprised of 
## approximately 5000 herds and the average number of cows per herd is 100.

epi.ssdetect(N = c(5000,100), pstar = c(0.08,0.05), se = c(0.90,0.95), 
   sp = c(0.80,0.85), interpretation = "parallel", 
   covar = c(0,0), nfractional = FALSE, se.psu = 0.95, ss.se = 0.95)

## We need to sample 46 cows from 40 herds (a total of 1840 samples).
## The sensitivity of this testing regime at the surveillance unit level 
## is 0.995. The specificity of this testing regime at the surveillance unit 
## level is 0.680.


## EXAMPLE 3:
## You want to document the absence of Mycoplasma from a 200-sow pig herd.
## Based on your experience and the literature, a minimum of 20% of sows  
## would have seroconverted if Mycoplasma were present in the herd. How many 
## sows do you need to sample?

epi.ssdetect(N = 200, pstar = 0.20, se = 0.95, sp = 1, 
   interpretation = "parallel", covar = c(0,0), nfractional = FALSE, 
   se.psu = 0.95, ss.se = 0.95)
   
## If you test 16 sows and all test negative you can state that you are 95% 
## confident that the prevalence rate of Mycoplasma in the herd is less than
## 20%.

Run the code above in your browser using DataLab